utils

package
v0.0.0-...-827206f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckEmailFormat

func CheckEmailFormat(email string) error

func GenerateToken

func GenerateToken(lengthByte int) (string, error)

Generate Token takes length of byte as integer and returns token as string

func HashToken

func HashToken(token string) string

HashToken takes token string and returns token hash string

func SendPasswordResetEmail

func SendPasswordResetEmail(email, token string) error

Types

This section is empty.

Jump to